import { Command, flags as flagtype } from "@oclif/command";
import { DocumentMetaResponse } from "@ironcorelabs/ironnode";
import * as GroupMaps from "../../lib/GroupMaps";
import { ErrorOr } from "../../lib/Utils";
declare type FileMetaResult = ErrorOr<{
    source: string;
    metadata: DocumentMetaResponse;
}>;
/**
 * File info command. Takes a single or multiple files as arguments and parses them for their IDs, then takes those IDs and looks up the meta information
 * from the SDk about the files. Displays results in a table.
 */
export default class Info extends Command {
    static description: string;
    static strict: boolean;
    static args: {
        name: string;
        description: string;
        required: boolean;
    }[];
    static flags: {
        help: import("@oclif/parser/lib/flags").IBooleanFlag<void>;
        keyfile: flagtype.IOptionFlag<string | undefined>;
    };
    static examples: string[];
    /**
     * Return a Promise to handle getting the meta information for a single file given it's relative path. Returns a result
     * structure that represents a success or error response.
     */
    getFileMetaPromise(filePath: string): Promise<FileMetaResult>;
    /**
     * Take the list of file meta results and groups by ID and create the display table, one row for each file we're getting information on.
     */
    buildResultTable(fileMeta: FileMetaResult[], groupsByID: GroupMaps.GroupsByID): import("cli-table3").GenericTable<import("cli-table3").Cell[]>;
    run(): Promise<void>;
}
export {};
