import { Command, flags as flagtype } from "@oclif/command";
import * as Table from "cli-table3";
import { GroupMetaResponse, GroupDetailResponse } from "@ironcorelabs/ironnode";
/**
 * Group info command. Retrieves a group given its name or ID and displays information about the group including the
 * members and admins if the requesting user is an admin.
 */
export default class Info extends Command {
    static description: string;
    static args: {
        name: string;
        description: string;
        required: boolean;
    }[];
    static flags: {
        help: import("@oclif/parser/lib/flags").IBooleanFlag<void>;
        keyfile: flagtype.IOptionFlag<string | undefined>;
    };
    static examples: string[];
    /**
     * Typeguard to determine which type of group detail response we have.
     */
    canSeeGroupDetails(group: GroupMetaResponse | GroupDetailResponse): group is GroupDetailResponse;
    /**
     * Build up the display table for group details. Displays the list of members and admins if the current
     * user is an admin of the group.
     */
    buildGroupDetailTable(group: GroupMetaResponse | GroupDetailResponse): Table.GenericTable<Table.VerticalTableRow>;
    run(): Promise<void>;
}
