"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@oclif/command");
const chalk_1 = require("chalk");
const SDK_1 = require("../../lib/SDK");
const Utils_1 = require("../../lib/Utils");
const sharedFlags_1 = require("../../lib/sharedFlags");
/**
 * Group list command. Retrieves all groups that the user is a part of and displays them in a table to the console.
 */
class List extends command_1.Command {
    async run() {
        this.parse(List);
        SDK_1.ironnode()
            .group.list()
            .then((groups) => {
            if (groups.result.length === 0) {
                return this.log("You aren't currently an admin or member of any groups.");
            }
            const table = Utils_1.createDisplayTable(["Group Name", "Admin", "Member", "Created", "Updated"]);
            const check = chalk_1.default.green("✔");
            const nope = chalk_1.default.red("✖");
            groups.result.map((group) => {
                table.push([
                    group.groupName,
                    group.isAdmin ? check : nope,
                    group.isMember ? check : nope,
                    new Date(group.created).toLocaleDateString(),
                    new Date(group.updated).toLocaleDateString(),
                ]);
            });
            this.log(`\n${table.toString()}\n`);
        })
            .catch((e) => {
            this.log(chalk_1.default.red(e.message));
            this.error(chalk_1.default.red("Failed to retrieve list of groups."));
        });
    }
}
List.description = "Display a list of all the groups of which you're either an admin or member.";
List.flags = {
    help: command_1.flags.help({ char: "h" }),
    keyfile: sharedFlags_1.keyFile(),
};
exports.default = List;
