import { Command } from "@oclif/command";
import * as IronNode from "@ironcorelabs/ironnode";
export default class Login extends Command {
    static aliases: string[];
    static description: string;
    private configFileHome;
    private defaultDeviceName;
    /**
     * Write out the provided device config to the provided file location.
     */
    storeNewDeviceKeys(configPath: string, configDetails: IronNode.DeviceDetails): boolean;
    /**
     * Generate device keys for a user that already exists. Checks if the users provided password was wrong and lets them retry. Once they get the right
     * password, use it to generate a new set of device keys and write them out.
     */
    generateExistingUserDeviceKeys(auth0Jwt: string): Promise<void>;
    /**
     * Sync a new user within the SDK. Ask the user for a password (verifying that it's non empty) and use it to generate a new user as well as an
     * initial set of device keys. Write out the device key details to the config path for future SDK operations.
     */
    generateNewUserAndDeviceKeys(auth0Jwt: string): Promise<void>;
    /**
     * Login the user by popping up an Auth0 login form and getting an Auth0 JWT. Then verify the user with the SDK to see if they exist. Then optionally
     * create the user and generating device keys which will be written out to a file for future command use.
     */
    loginUser(): Promise<void>;
    /**
     * Run the login command. Check to see if this device already has keys. If not kick off the login process.
     */
    run(): Promise<void>;
}
