"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@oclif/command");
const chalk_1 = require("chalk");
const cli_ux_1 = require("cli-ux");
const fs = require("fs");
const SDK_1 = require("../lib/SDK");
/**
 * Logout command. Confirms that the user wants to delete their local keys and if so, removes the public keys from the identity DB and
 * the private keys from their filesystem.
 */
class Logout extends command_1.Command {
    async run() {
        this.parse(Logout);
        const deviceKeysLocation = `${this.config.home}/.iron/keys`;
        const doDelete = await cli_ux_1.default.confirm(`${chalk_1.default.magenta("Really deauthorize this device and remove local private keys?")} ${chalk_1.default.gray("[y/n]")}`);
        if (!doDelete) {
            return this.exit(0);
        }
        try {
            const SDK = SDK_1.ironnode();
            if (!SDK) {
                throw new Error(); //No message for this error as we don't display it below in the catch
            }
            await SDK_1.ironnode().user.deleteDevice();
        }
        catch (_a) {
            this.log(chalk_1.default.red("Failed to deauthroize device keys from key server, but still attempting to delete local device keys."));
        }
        try {
            fs.accessSync(deviceKeysLocation, fs.constants.W_OK);
            fs.unlinkSync(deviceKeysLocation);
            this.log(chalk_1.default.green("You have been logged out. Use 'ironhide login' to log back in and authorize this device again."));
        }
        catch (e) {
            this.log(e);
            this.error(chalk_1.default.red(`Failed to remove local device keys as the key file ('${deviceKeysLocation}') could not be deleted.`));
        }
    }
}
Logout.description = "Logout of ironhide and delete any local private keys. Those keys will also be deauthorized so they can no longer decrypt your data.";
exports.default = Logout;
