import { Command, flags as flagtype } from "@oclif/command";
import { ErrorOr } from "../../lib/Utils";
declare type DeviceDeleteResult = ErrorOr<{
    id: number;
}>;
/**
 * Delete one to many devices given their ID. Verifies that the user isn't trying to use this command to delete the device they're on and makes requests
 * in parallel to delete devices for each ID provided.
 */
export default class DeviceDelete extends Command {
    static aliases: string[];
    static description: string;
    static args: {
        name: string;
        description: string;
        required: boolean;
    }[];
    static strict: boolean;
    static flags: {
        help: import("@oclif/parser/lib/flags").IBooleanFlag<void>;
        keyfile: flagtype.IOptionFlag<string | undefined>;
    };
    static examples: string[];
    /**
     * Return a Promise operation to delete the provided device ID. Maps any failures into successes so we can display information about each
     * result back to the user.
     */
    getDeviceDeletePromise(deviceID: string): Promise<DeviceDeleteResult>;
    /**
     * Check if the user is attempting to delete the device keys that they're currently using. If so display an error.
     */
    checkDeletionOfCurrentDevice(deviceIDs: string[]): Promise<void>;
    run(): Promise<void>;
}
export {};
