"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@oclif/command");
const chalk_1 = require("chalk");
const SDK_1 = require("../../lib/SDK");
const Utils_1 = require("../../lib/Utils");
const sharedFlags_1 = require("../../lib/sharedFlags");
/**
 * User device list command. Gets a list of a users devices and displays their ID, name, timestamps, and whether the device is their current device.
 */
class DeviceList extends command_1.Command {
    /**
     * Build up a table that adds a row for each device and shows the device ID, name, and created and updated times in an easier to read format
     */
    buildUserKeyTable(devices) {
        const table = Utils_1.createDisplayTable(["Device ID", "Device Name", "Created", "Updated", "Current Device"]);
        devices.result
            .sort((a, b) => (new Date(a.created) > new Date(b.created) ? 1 : -1))
            .forEach((device) => {
            const currentDevice = device.isCurrentDevice ? chalk_1.default.green("✔") : "";
            table.push([device.id, device.name, new Date(device.created).toLocaleString(), new Date(device.updated).toLocaleString(), currentDevice]);
        });
        return table;
    }
    async run() {
        this.parse(DeviceList);
        try {
            const devices = await SDK_1.ironnode().user.listDevices();
            this.log(`\n${this.buildUserKeyTable(devices).toString()}\n`);
        }
        catch (e) {
            this.error(chalk_1.default.red("Failed to retrieve list of device keys."));
        }
    }
}
DeviceList.aliases = ["user:deviceList"];
DeviceList.description = "List all of the devices authorized to decrypt your data.";
DeviceList.flags = {
    help: command_1.flags.help({ char: "h" }),
    keyfile: sharedFlags_1.keyFile(),
};
exports.default = DeviceList;
