"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@oclif/command");
const chalk_1 = require("chalk");
const SDK_1 = require("../../lib/SDK");
const Utils_1 = require("../../lib/Utils");
const sharedFlags_1 = require("../../lib/sharedFlags");
/**
 * User lookup command. Attempts to retrieve public keys for a list of users given their email addresses.
 */
class Lookup extends command_1.Command {
    /**
     * Build up a table that adds a row for each key result row which either displays the users public key or an error message
     * saying that the user has yet to create an account.
     */
    buildUserKeyTable(userKeys) {
        const table = Utils_1.createDisplayTable(["User ID", "Public Key"]);
        Object.keys(userKeys).forEach((userID) => {
            const userPublicKey = userKeys[userID];
            table.push([
                userID,
                userPublicKey !== null ? chalk_1.default.green(`${userPublicKey.x}\n${userPublicKey.y}`) : chalk_1.default.red("User hasn't created an account yet."),
            ]);
        });
        return table;
    }
    async run() {
        const { argv } = this.parse(Lookup);
        SDK_1.ironnode()
            .user.getPublicKey(argv)
            .then((userKeys) => {
            this.log(`\n${this.buildUserKeyTable(userKeys).toString()}\n`);
        })
            .catch((_) => {
            this.error(chalk_1.default.red("Failed to retrieve keys for the provided user IDs."));
        });
    }
}
Lookup.description = "See if a user is signed up and get their public keys using their email address.";
Lookup.args = [
    {
        name: "users",
        description: "One or more user emails to lookup.",
        required: true,
    },
];
Lookup.strict = false; //This command supports unlimited arguments
Lookup.flags = {
    help: command_1.flags.help({ char: "h" }),
    keyfile: sharedFlags_1.keyFile(),
};
Lookup.examples = [Utils_1.buildCommandSampleText(`user:lookup test@example.com test2@example.com`)];
exports.default = Lookup;
