import * as Table from "cli-table3";
import { DocumentAccessList, DocumentAccessResponse } from "@ironcorelabs/ironnode";
import { GroupsByID } from "./GroupMaps";
export declare type ErrorOr<R> = R | Error;
interface ProcessFileBase {
    out?: string;
    deleteSource: boolean;
}
export interface ProcessSingleFileOp extends ProcessFileBase {
    file: string;
}
export interface ProcessMultipleFileOp extends ProcessFileBase {
    file: string[];
}
export interface ProcessStdinOp {
    out: string;
}
export declare type ProcessFileOp = ProcessSingleFileOp | ProcessMultipleFileOp;
export declare type ProcessOp = ProcessFileOp | ProcessStdinOp;
/**
 * Type guard to determine if the file options we have represents a multiple file operation.
 */
export declare function isMultipleFileOperation(fileProcessOp: ProcessOp): fileProcessOp is ProcessMultipleFileOp;
/**
 * Type guard to determine if the file options we have represent an operation from stdin.
 */
export declare function isStdInFileOperation(fileProcessOp: ProcessOp): fileProcessOp is ProcessStdinOp;
/**
 * Type guard to determine of ErrorOr result is an Error instance.
 */
export declare function isError<R>(result: ErrorOr<R>): result is Error;
/**
 * Returns whether or not the file provided both exists and is readable.
 */
export declare function isFileReadable(path: string): boolean;
/**
 * Check to see if the provided device key config file is parsable and formatted correctly.
 */
export declare function validateExistingKeys(configPath: string): false | "" | 0 | {
    publicKey: string;
    privateKey: string;
};
/**
 * Attempt to normalize and create a fully qualified path given either an existing fully qualified path
 * or a partial path. If the provided path starts with / it assumes it's already fully qualified, otherwise
 * it normalizes the path from the cwd.
 */
export declare function normalizePathToFile(file: string): string;
/**
 * Attempt to delete the provided partial file path. Will throw an exception if the file isn't writable and cannot be deleted.
 */
export declare function deleteFile(filePath: string): void;
/**
 * Validate that the provided file to encrypt is readable and is an actual file.
 */
export declare function checkSourceFilePermissions(fileToEncrypt: string): Promise<void>;
/**
 * Check that the file path to write to doesn't already exist and the directory it will live in is writable.
 */
export declare function checkDestinationFilePermissions(destinationFile: string): Promise<void>;
/**
 * Given an optional list of users and groups convert them into an object that the SDK takes for user and group shares.
 */
export declare function convertUserAndGroupToAccessList(providedUserIDs: string[] | undefined, providedGroupIDs: string[] | undefined): DocumentAccessList;
/**
 * Creates a new CLI table from the provided columns. Centralized method to return the proper type as well as change
 * the table headers from their default of red (bad!) to blue (nice!).
 */
export declare function createDisplayTable(columns: string[]): Table.GenericTable<Table.Cell[]>;
/**
 * Convert a grant/revoke response object into a CLI table for which displays the list of successes and failures
 */
export declare function fileAccessResponseToTableRow(fileSource: string, accessResult: DocumentAccessResponse, groupsByID: GroupsByID): string[];
/**
 * Build up example command text which support for providing an optional description of the example. All examples are prefixed with a `$ ironhide` to avoid
 * duplication of that for each command.
 */
export declare function buildCommandSampleText(example: string, description?: string, showPrefix?: boolean): string;
export {};
